@@ -301,7 +301,7 @@
 /*
  * When pasting ACS characters, convert to similar normal characters
  */
-/* #define ACS_ASCII */
+#define ACS_ASCII
 
 /*
  * Default ascii characters to which ACS symbols are converted
@@ -490,7 +490,7 @@
 #define DEFAULT_MIN_VISIBLE_TABS    (6)
 
 /* Minimum Xft font size (pixel) */
-#define MIN_XFT_FONT_SIZE	    (8)
+#define MIN_XFT_FONT_SIZE	    (1)
 
 /* Default Xft font name and size */
 #define DEFAULT_XFT_FONT_SIZE	    (12)
