@@ -41,6 +41,8 @@ static const char *const macroNames[] =
     "Scroll",		    /* Scroll up/down */
     "Copy",		    /* Copy selection */
     "Paste",		    /* Paste selection */
+    "PasteFile",	    /* Paste the content of a file */
+    "MonitorTab",	    /* Monitor tab for activity/inactivity */
     "ToggleSubwin",	    /* Toggle subwindows (scroll / menu / tabbar) */
     "ResizeFont",	    /* Resize terminal font */
     "ToggleVeryBold",	    /* Toggle use of bold font for colored text */
@@ -63,7 +65,7 @@ static const char *const macroNames[] =
 * 		       BEGIN INTERNAL ROUTINE PROTOTYPES		       *
 \******************************************************************************/
 int		macro_cmp	    ( const void*, const void*);
-int		rxvt_add_macro	    ( rxvt_t*, KeySym, unsigned char, char*, Bool, Bool);
+int		rxvt_add_macro	    ( rxvt_t*, KeySym, unsigned char, char*, Bool, macro_priority_t);
 unsigned char	macro_set_number    ( unsigned char, unsigned char);
 /******************************************************************************\
 *			END INTERNAL ROUTINE PROTOTYPES			       *
@@ -247,7 +249,8 @@ macro_set_number( unsigned char flag, unsigned char num )
 /* EXTPROTO */
 #define NEWARGLIM   500	/* `reasonable' size */
 int
-rxvt_parse_macros( rxvt_t *r, const char *str, const char *arg, Bool noReplace)
+rxvt_parse_macros( rxvt_t *r, const char *str, const char *arg,
+	macro_priority_t priority)
 {
     char	    newarg[NEWARGLIM],
 		    keyname[ NEWARGLIM],
@@ -294,7 +297,8 @@ rxvt_parse_macros( rxvt_t *r, const char *str, const char *arg, Bool noReplace)
     newarg[NEWARGLIM - 1] = '\0';
     rxvt_str_trim( newarg );
 
-    rxvt_msg (DBG_INFO, DBG_MACROS, "Got macro '%s' -- '%s'\n", keyname, newarg );
+    rxvt_msg( DBG_INFO, DBG_MACROS,
+	    "Got macro '%s' -- '%s'\n", keyname, newarg );
 
     /*
      * Breakup keyname into a keysym and modifier flags.
@@ -330,10 +334,13 @@ rxvt_parse_macros( rxvt_t *r, const char *str, const char *arg, Bool noReplace)
     }
 
     /*
-     * Always store the keysym as lower case. That way we can treat shift
+     * Always store the keysym as upper case. That way we can treat shift
      * correctly even when Caps Lock is pressed.
      */
-    keysym = tolower( XStringToKeysym( keyname_nomods ) );
+    {
+        KeySym upper;
+        XConvertCase(XStringToKeysym(keyname_nomods), &keysym, &upper);
+    }
 
     if (NOT_KEYSYM(keysym))
     {
@@ -342,22 +349,24 @@ rxvt_parse_macros( rxvt_t *r, const char *str, const char *arg, Bool noReplace)
 	return -1;
     }
 
-    return rxvt_add_macro( r, keysym, modFlags, newarg, addmacro, noReplace)
+    return rxvt_add_macro( r, keysym, modFlags, newarg, addmacro, priority)
 		? 1 : -1;
 }
 
-/* {{{1 rxvt_add_macro( keysym, modFlags, astring, noreplace)
+/* {{{1 rxvt_add_macro( keysym, modFlags, astring, priority)
  *
  * Add a macro to our list of macros (r->macros) if astring describes a valid
- * macro. If keysym == None, then add the macro to the previous one.
+ * macro.
  *
- * If noReplace is true, don't replace existing macros. Required when reading
- * the system config file so that we don't replace existing user macros.
+ * priority is the priority with which the macro should be added. A macro should
+ * never overwrite a macro with lower priority (yes, I know that's backwards). A
+ * macro should be added to a chain ONLY IF it's priority is the same as the
+ * previous macro's priority.
  */
 /* INTPROTO */
 int
 rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
-	Bool addmacro, Bool noReplace)
+	Bool addmacro, macro_priority_t priority)
 {
     const unsigned nmacros_increment = 64;  /* # extra macros to alloc space for
 					       when we need to enlarge our list
@@ -372,7 +381,8 @@ rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
     action_t	    action;
 
 
-    rxvt_dbgmsg ((DBG_DEBUG, DBG_MACROS, "rxvt_add_macro(%08lx, %2hhx, %s)\n", keysym, modFlags, astring));
+    rxvt_dbgmsg(( DBG_DEBUG, DBG_MACROS, "%s(%08lx, %2hhx, '%s', %d, %d)\n",
+		__func__, keysym, modFlags, astring, addmacro, priority ));
 
     /*
      * Check to see if macro already exists.
@@ -385,7 +395,7 @@ rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
 		    == (modFlags & MACRO_MODMASK & ~MACRO_PRIMARY)
 	  )
 	{
-	    if( addmacro )
+	    if( addmacro && r->macros[i].priority == priority )
 	    {
 		/*
 		 * Find the last macro in the macro chain (the macro with the
@@ -407,10 +417,10 @@ rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
 	    }
 
 	    /*
-	     * Macro for key already exists. If noReplace is set, don't
-	     * touch this macro.
+	     * Macro for key already exists. Only replace it if we have a
+	     * *lower* priority (which in theory should never happen).
 	     */
-	    else if( noReplace )
+	    else if( priority > r->macros[i].priority )
 		return 1; /* Claim to have succeded so that caller will not
 			     complain about "Failing to add a ... macro". */
 	    
@@ -453,17 +463,37 @@ rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
     {
 	if( replaceIndex == r->nmacros )
 	{
-	    rxvt_msg (DBG_ERROR, DBG_MACROS,  "No previous macro to add to (key %s%s%s%s)",
+	    rxvt_msg( DBG_ERROR, DBG_MACROS,
+		    "No previous macro to add to (key %s%s%s%s)",
 		    (modFlags & MACRO_CTRL) ? "Ctrl+" : "",
 		    (modFlags & MACRO_META) ? "Meta+" : "",
 		    (modFlags & MACRO_SHIFT) ? "Shift+" : "",
 		    XKeysymToString( keysym ) );
 	    return 0;	/* Failure */
 	}
+
+	else if( r->macros[replaceIndex].priority != priority )
+	{
+	    rxvt_msg( DBG_ERROR, DBG_MACROS,
+		    "Can not add to a macro defined at a different location "
+		    "(key %s%s%s%s)",
+		    (modFlags & MACRO_CTRL) ? "Ctrl+" : "",
+		    (modFlags & MACRO_META) ? "Meta+" : "",
+		    (modFlags & MACRO_SHIFT) ? "Shift+" : "",
+		    XKeysymToString( keysym ) );
+	    return 0;	/* Failure */
+	}
+
 	else if( r->macros[replaceIndex].action.type == MacroFnDummy )
 	{
 	    /* Do not add to a dummy macro */
-	    rxvt_msg (DBG_ERROR, DBG_MACROS,  "Can not add actions to a Dummy macro" );
+	    rxvt_msg (DBG_ERROR, DBG_MACROS,
+		    "Can not add actions to a Dummy macro"
+		    "(key %s%s%s%s)",
+		    (modFlags & MACRO_CTRL) ? "Ctrl+" : "",
+		    (modFlags & MACRO_META) ? "Meta+" : "",
+		    (modFlags & MACRO_SHIFT) ? "Shift+" : "",
+		    XKeysymToString( keysym ) );
 	    return 0;	/* Failure */
 	}
 
@@ -519,7 +549,7 @@ rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
      */
     assert( astring );
     SET_NULL(action.str);   /* Make sure rxvt_set_action won't free non-existent
-			   memory */
+			       memory */
     if( !rxvt_set_action( &action, astring) )
 	return 0; /* Failure: Probably unrecognized action type */
 
@@ -529,8 +559,16 @@ rxvt_add_macro( rxvt_t *r, KeySym keysym, unsigned char modFlags, char *astring,
     r->macros[replaceIndex].keysym	= keysym;
     r->macros[replaceIndex].modFlags	= modFlags;
     r->macros[replaceIndex].action	= action;
+    r->macros[replaceIndex].priority	= priority;
 
-    rxvt_dbgmsg ((DBG_DEBUG, DBG_MACROS, "Added macro %hu of %hu. Type %s, len %hu, args '%s'.\n", replaceIndex, r->maxMacros, macroNames[ action.type ], action.len, (action.type == MacroFnStr || action.type == MacroFnEsc) ?  "(escaped string)" : (IS_NULL(action.str) ? "(nil)" : (char*) action.str)));
+    rxvt_dbgmsg(( DBG_DEBUG, DBG_MACROS,
+		"Added macro %hu of %hu. Type %s, len %hu, args '%s'.\n",
+		replaceIndex, r->maxMacros, macroNames[ action.type ],
+		action.len,
+		(action.type == MacroFnStr || action.type == MacroFnEsc) ?
+		    "(escaped string)" :
+		    (IS_NULL(action.str) ?
+			"(nil)" : (char*) action.str)));
 
     return 1;	/* Success */
 }
@@ -595,7 +633,9 @@ rxvt_cleanup_macros( rxvt_t *r )
 	r->maxMacros = r->nmacros;
     }
 
-    rxvt_dbgmsg ((DBG_DEBUG, DBG_MACROS, "Read %d macros. (Have space for %d macros)\n", r->nmacros, r->maxMacros));
+    rxvt_dbgmsg(( DBG_DEBUG, DBG_MACROS,
+		"Read %d macros. (Have space for %d macros)\n",
+		r->nmacros, r->maxMacros));
 }
 
 /* {{{1 rxvt_set_action( action, astring)
@@ -703,8 +743,11 @@ rxvt_process_macros( rxvt_t *r, KeySym keysym, XKeyEvent *ev)
     if (ev->state & ControlMask)	    ck.modFlags |= MACRO_CTRL;
     if (ev->state & r->h->ModMetaMask)	    ck.modFlags |= MACRO_META;
 
-    /* Use lowercase version so we can ignore caps lock */
-    ck.keysym = tolower( keysym );
+    /* Use uppercase version so we can ignore caps lock */
+    {
+        KeySym upper;
+        XConvertCase(keysym, &ck.keysym, &upper);
+    }
 
     /* Check if macro ck is in our list of macros. */
     macro = bsearch( &ck, r->macros, r->nmacros, sizeof( macros_t ),
@@ -824,13 +867,14 @@ rxvt_dispatch_action( rxvt_t *r, action_t *action, XEvent *ev)
 		/* See if a profile is specified */
 		if( *command == '-' )
 		{
-		    profile = (int) ( *(++command) - '0' );
+		    char *pnum_end;
+		    profile = strtoul( ++command, &pnum_end, 0 );
 
 		    if( profile < 0 || profile >= MAX_PROFILES )
 			profile = AVTS(r)->profileNum;
 
 		    /* Skip spaces */
-		    if( *command  ) command++;
+		    command = pnum_end;
 		    while( isspace( *command ) ) command++;
 		}
 
@@ -990,11 +1034,110 @@ rxvt_dispatch_action( rxvt_t *r, action_t *action, XEvent *ev)
 	case MacroFnCopy:
 #endif
 	case MacroFnPaste:
+	{
+	    int sel = XA_PRIMARY;
+
 	    if (NOT_NULL(ev))
-		rxvt_selection_request (r, ATAB(r), ev->xkey.time, 0, 0);
+	    {
+		if( NOT_NULL(astr) && *astr )
+		{
+		    if(strcmp ("PRIMARY", astr) == 0)
+			sel=XA_PRIMARY;
+		    else if (strcmp ("SECONDARY", astr) == 0)
+		      sel=XA_SECONDARY;
+		    else if (strcmp ("CLIPBOARD", astr) == 0)
+		      sel=XA_CLIPBOARD;
+		    else
+		      break;
+		    rxvt_selection_request_by_sel( r, ATAB(r), ev->xkey.time,
+			    0, 0, sel);
+		}
+		else
+		    rxvt_selection_request (r, ATAB(r), ev->xkey.time, 0, 0);
+	    }
+	    else
+	    {
+		retval = -1;
+	    }
+	    break;
+	}
+
+	case MacroFnPasteFile:
+	{
+	    if (NOT_NULL(ev))
+	    {
+	        if( NOT_NULL(astr) && *astr )
+		    rxvt_paste_file (r, ATAB(r), ev->xkey.time, 0, 0, astr);
+	        else
+		    break;
+	    }
 	    else
 		retval = -1;
+
+	   break;
+	}
+
+	case MacroFnMonitorTab:
+	{
+	    if (NOT_NULL(ev))
+	    {
+		if( NOT_NULL(astr) && *astr )
+		{
+		    short doit = 0;
+
+		    /* which monitoring type do we need ? */
+		    if(strcmp ("ACTIVITY", astr) == 0)
+		    {
+		      AVTS(r)->monitor_tab = 
+			  (AVTS(r)->monitor_tab == TAB_MON_ACTIVITY ) ? TAB_MON_OFF : TAB_MON_ACTIVITY;
+		      doit = 1;
+		      rxvt_msg (DBG_INFO, DBG_MACROS,  "Macro %s ACTIVITY : activity monitoring request on tab %i.",
+			macroNames[action->type], AVTS(r)->vts_idx );
+		    }
+		    else if (strcmp ("INACTIVITY", astr) == 0)
+		    {
+		      AVTS(r)->monitor_tab = 
+			  (AVTS(r)->monitor_tab == TAB_MON_INACTIVITY) ? TAB_MON_OFF : TAB_MON_INACTIVITY;
+		      doit = 1;
+		      rxvt_msg (DBG_INFO, DBG_MACROS,  "Macro %s INACTIVITY : inactivity monitoring request on tab %i.",
+		 	 macroNames[action->type], AVTS(r)->vts_idx );
+		    }
+		    else if (strcmp ("AUTO", astr) == 0)
+		    {
+		      AVTS(r)->monitor_tab = 
+			  (AVTS(r)->monitor_tab == TAB_MON_AUTO) ? TAB_MON_OFF : TAB_MON_AUTO;
+		      doit = 1;
+		      rxvt_msg (DBG_INFO, DBG_MACROS,  
+			 "Macro %s AUTO : request for automatic (in-)activity monitoring on tab %i.",
+		 	 macroNames[action->type], AVTS(r)->vts_idx );
+		    }
+		    else
+		    {
+		      rxvt_msg (DBG_INFO, DBG_MACROS,  "Macro %s requires argument or invalid argument provided.",
+		 	 macroNames[action->type] );
+		      break;
+		    }
+		    /* activating/deactivating the macro */
+		    if (doit != 0)
+		    {
+		      if (AVTS(r)->monitor_tab == TAB_MON_OFF )
+		      {
+			  rxvt_msg (DBG_INFO, DBG_MACROS,  "Macro %s was already active, deactivating previous macro call.",
+			     macroNames[action->type] );
+		      }else
+		      {
+			  AVTS(r)->monitor_nbytes_read = 0;
+			  gettimeofday( &AVTS(r)->monitor_start , NULL);
+		      }
+		    }
+		}
+	    }
+	    else
+	    {
+		retval = -1;
+	    }
 	    break;
+	}
 
 	case MacroFnToggleSubwin:
 	    rxvt_toggle_subwin( r, (unsigned char*) astr);
@@ -1045,7 +1188,34 @@ rxvt_dispatch_action( rxvt_t *r, action_t *action, XEvent *ev)
 	    break;
 
 	case MacroFnToggleBcst:
-	    TOGGLE_OPTION(r, Opt2_broadcast);
+	    if( NOT_NULL(astr) && *astr )
+	    {
+		long state = strtol( astr, NULL, 0 );
+
+		switch(state)
+		{
+		    case 1:
+			SET_OPTION( r, Opt2_broadcast );
+			break;
+
+		    case 0:
+			UNSET_OPTION( r, Opt2_broadcast );
+			break;
+
+		    case -1:
+			TOGGLE_OPTION( r, Opt2_broadcast );
+			break;
+
+		    default:
+			rxvt_msg( DBG_ERROR, DBG_MACROS,
+				"Badly formed argument '%s' to %s\n",
+				astr, macroNames[action->type] );
+			retval = -1;
+			break;
+		}
+	    }
+	    else
+		TOGGLE_OPTION(r, Opt2_broadcast);
 	    break;
 
 	case MacroFnToggleHold:
