@@ -27,18 +27,6 @@
 #include "rxvt.h"
 
 
-#ifdef DEBUG_VERBOSE
-#define DEBUG_LEVEL 1
-#else 
-#define DEBUG_LEVEL 0
-#endif
-
-#if DEBUG_LEVEL
-#define DBG_MSG(d,x) if(d <= DEBUG_LEVEL) fprintf x
-#else
-#define DBG_MSG(d,x)
-#endif
-
 
 /* EXTPROTO */
 char*
@@ -50,23 +38,6 @@ rxvt_r_basename(const char *str)
 }
 
 
-/*
- * Print an error message
- */
-/* EXTPROTO */
-void
-rxvt_print_error(const char *fmt,...)
-{
-    va_list         arg_ptr;
-
-    va_start(arg_ptr, fmt);
-    fprintf(stderr, APL_NAME ": ");
-    vfprintf(stderr, fmt, arg_ptr);
-    fprintf(stderr, "\n");
-    va_end(arg_ptr);
-}
-
-
 /*
  * check that the first characters of S1 match S2
  *
@@ -248,7 +219,10 @@ rxvt_str_escaped(char *str)
     return (d - str);
 }
 
-/* % interpolate expand src, and copy into dst */
+/*
+ * % interpolate expand src, and copy into dst. Returns length of the
+ * interpolated string.
+ */
 /* EXTPROTO */
 int
 rxvt_percent_interpolate( rxvt_t *r, int page,
@@ -257,8 +231,11 @@ rxvt_percent_interpolate( rxvt_t *r, int page,
     int	i=0,	/* Unexpanded string index */
 	j=0;	/* Expanded string index */
 
-    DBG_MSG( 2, (stderr, "rxvt_percent_interpolate( r, %d, %s, %d, %s, %d )\n",
-	    page, src, len, "dst", maxLen ));
+    rxvt_dbgmsg ((DBG_DEBUG, DBG_MISC, "rxvt_percent_interpolate( r, %d, %s, %d, %s, %d )\n", page, src, len, "dst", maxLen));
+
+    /* Must only get here for a valid tab */
+    assert( page >=0 && page <= LTAB(r) );
+    assert( NOT_NULL( PVTS( r, page ) ) && PVTS( r, page )->vts_idx != -1 );
 
     while( i < len-1 && j < maxLen-1 )
     {
@@ -325,9 +302,28 @@ rxvt_percent_interpolate( rxvt_t *r, int page,
 		    i++;
 		    break;
 
+		case 'P':
+		    /* PID of mrxvt */
+		    j += snprintf( dst + j, maxLen - j, "%d", getpid() );
+		    i++;
+		    break;
+
+		case 'G':
+		    /* Global tab number (plus 1) */
+		    j += snprintf( dst + j, maxLen - j, "%d",
+			    PVTS( r, page )->globalTabNum + 1 );
+		    i ++;
+		    break;
+
+		case 'T':
+		    /* # tabs created so far */
+		    j += snprintf( dst + j, maxLen - j, "%d",
+			    r->ntabs + 1 );
+		    i ++;
+		    break;
+
 		default:
-		    rxvt_print_error( "Unrecognized switch %%%c in '%s'",
-			    src[i++], src );
+		    rxvt_msg (DBG_ERROR, DBG_MISC, "Unrecognized flag %%%c in '%s'", src[i++], src );
 		    break;
 	    }
 	}
@@ -394,8 +390,6 @@ rxvt_splitcommastring(const char *cs)
  * file searching
  */
 
-/* #define DEBUG_SEARCH_PATH */
-
 #if defined (BACKGROUND_IMAGE) || defined (HAVE_MENUBAR)
 /*
  * search for FILE in the current working directory, and within the
@@ -418,10 +412,10 @@ rxvt_File_search_path(const char *pathlist, const char *file, const char *ext)
     if ((p = STRCHR(file, ';'))) len = (p - file);
     else len = STRLEN(file);
 
-#ifdef DEBUG_SEARCH_PATH
+#ifdef DEBUG
     getcwd(name, sizeof(name));
-    fprintf(stderr, "pwd: \"%s\"\n", name);
-    fprintf(stderr, "find: \"%.*s\"\n", len, file);
+    rxvt_dbgmsg ((DBG_VERBOSE, DBG_MISC, "pwd: \"%s\"\n", name));
+    rxvt_dbgmsg ((DBG_VERBOSE, DBG_MISC, "find: \"%.*s\"\n", len, file));
 #endif
 
     /* leave room for an extra '/' and trailing '\0' */
@@ -494,8 +488,7 @@ rxvt_File_find(const char *file, const char *ext, const char *path)
 	 * Failed to get the file from arg path. Try getting it from the env
 	 * variable PATH_ENV.
 	 */
-	DBG_MSG( 2, ( stderr, "Searching for %s from env %s...\n",
-		    file, PATH_ENV));
+	rxvt_dbgmsg ((DBG_DEBUG, DBG_MISC, "Searching for %s from env %s...\n", file, PATH_ENV));
 
 	envpath = getenv( PATH_ENV);
 	if( envpath)
@@ -504,7 +497,7 @@ rxvt_File_find(const char *file, const char *ext, const char *path)
 	/*
 	 * Check in ~/.mrxvt
 	 */
-	DBG_MSG( 2, ( stderr, "Searching for %s in ~/.mrxvt\n", file));
+	rxvt_dbgmsg ((DBG_DEBUG, DBG_MISC, "Searching for %s in ~/.mrxvt\n", file));
 	envpath = getenv("HOME");
 	if( envpath )
 	{
@@ -522,14 +515,13 @@ rxvt_File_find(const char *file, const char *ext, const char *path)
 	/*
 	 * Last resort: Try a compiled in default.
 	 */
-	DBG_MSG( 2, ( stderr, "Searching for %s in %s\n",
-		    file, PKG_CONF_DIR));
+	rxvt_dbgmsg ((DBG_DEBUG, DBG_MISC, "Searching for %s in %s\n", file, PKG_CONF_DIR));
 	f = rxvt_File_search_path( PKG_CONF_DIR, file, ext);
      }
     while(0);
 
 
-    DBG_MSG( 2, ( stderr, "Got file %s\n", f ? f : "(nil)"));
+    rxvt_dbgmsg ((DBG_DEBUG, DBG_MISC, "Got file %s\n", f ? f : "(nil)"));
     return f;
 }
 #endif		    /* defined (BACKGROUND_IMAGE) || (HAVE_MENUBAR) */
