@@ -27,19 +27,6 @@
 #include "rxvt.h"
 
 
-#ifdef DEBUG_VERBOSE
-#define DEBUG_LEVEL 1
-#else 
-#define DEBUG_LEVEL 0
-#endif
-
-#if DEBUG_LEVEL
-#define DBG_MSG(d,x) if(d <= DEBUG_LEVEL) fprintf x
-#else
-#define DBG_MSG(d,x)
-#endif
-
-
 #ifdef BACKGROUND_IMAGE
 
 /*--------------------------------------------------------------------*
@@ -434,7 +421,7 @@ rxvt_load_pixmap(rxvt_t *r, const char *file, long* pwidth, long* pheight)
 	/* semi-colon delimited */
 	if (NULL == (p = STRCHR(file, ';')))
 	    p = STRCHR(file, '\0');
-	rxvt_print_error("couldn't load image file \"%.*s\"", (p - file), file);
+	rxvt_msg (DBG_ERROR, DBG_PIXMAP, "couldn't load image file \"%.*s\"", (p - file), file);
 	return None;
     }
 
@@ -479,7 +466,7 @@ rxvt_load_pixmap(rxvt_t *r, const char *file, long* pwidth, long* pheight)
 	/* semi-colon delimited */
 	if ((p = STRCHR(file, ';')) == NULL)
 	p = STRCHR(file, '\0');
-	rxvt_print_error("couldn't load image file \"%.*s\"", (p - file), file);
+	rxvt_msg (DBG_ERROR, DBG_PIXMAP, "couldn't load image file \"%.*s\"", (p - file), file);
     }
 
     return  (pixmap);
