@@ -71,7 +71,7 @@ int              greek_xlat                       __PROTO((char* s, int num_char
 /* End prototypes of grkelot.c */
 
 /* Begin prototypes of macros.c */
-int		 rxvt_parse_macros		  __PROTO((rxvt_t*, const char *, const char *, Bool noReplace));
+int		 rxvt_parse_macros		  __PROTO((rxvt_t*, const char *, const char *, macro_priority_t priority));
 void		 rxvt_cleanup_macros		  __PROTO((rxvt_t*));
 Bool		 rxvt_set_action		  __PROTO((action_t*, char*));
 int		 rxvt_process_macros		  __PROTO((rxvt_t*, KeySym, XKeyEvent*));
@@ -274,11 +274,13 @@ void             rxvt_selection_check             __PROTO((rxvt_t* r, int page,
 int              rxvt_selection_paste             __PROTO((rxvt_t* r, Window win, Atom prop, Bool delete_prop));
 void             rxvt_selection_property          __PROTO((rxvt_t* r, Window win, Atom prop));
 void             rxvt_selection_request           __PROTO((rxvt_t* r, int page, Time tm, int x, int y));
+void             rxvt_selection_request_by_sel    __PROTO((rxvt_t* r, int page, Time tm, int x, int y, int sel));
 void             rxvt_process_selectionclear      __PROTO((rxvt_t* r, int page));
 void             rxvt_selection_make              __PROTO((rxvt_t* r, int page, Time tm));
 void             rxvt_selection_click             __PROTO((rxvt_t* r, int page, int clicks, int x, int y));
 void             rxvt_selection_extend            __PROTO((rxvt_t* r, int page, int x, int y, int flag));
 void             rxvt_selection_rotate            __PROTO((rxvt_t* r, int page, int x, int y));
+void             rxvt_paste_file                  __PROTO((rxvt_t* r, int page, Time tm, int x, int y, char* filename));
 void             rxvt_process_selectionrequest    __PROTO((rxvt_t* r, int page, const XSelectionRequestEvent *rq));
 void             rxvt_pixel_position              __PROTO((rxvt_t* r, int *x, int *y));
 /* End prototypes of screen.c */
