@@ -188,6 +188,10 @@ typedef struct {
 # include <pty.h>
 #endif
 
+#ifdef OS_DARWIN
+# include <util.h>
+#endif
+
 #ifdef OS_QNX
 # include <process.h>
 # include <sys/utsname.h>
@@ -215,7 +219,6 @@ typedef struct {
 #endif
 
 
-#ifdef HAVE_LIBX11
 # include <X11/Xlib.h>
 # include <X11/X.h>
 # include <X11/Xutil.h>
@@ -242,7 +245,6 @@ typedef struct {
 # ifdef HAVE_X11_SM_SMLIB_H
 #  include <X11/SM/SMlib.h>
 # endif
-#endif
 
 /* Macros to check X Window IDs. Notice that we can use only one macro
 ** to check all different type of IDs such as Window and Pixmap. But it
@@ -347,14 +349,12 @@ typedef char*	    XPointer;
 
 /* Xft.h seems to conflict with png.h. So we must include it
 ** after pnt.h */
-#ifdef HAVE_LIBX11
 # ifdef XFT_SUPPORT
 #  include <X11/Xft/Xft.h>
 # endif
 # ifdef HAVE_ICONV_H
 #  include <iconv.h>
 # endif
-#endif
 
 /*
 ** It seems Mac OS X's fontconfig does not have following definitions
@@ -1176,7 +1176,12 @@ enum {
 
     Rs_focusDelay,
 
+#ifndef NO_BELL
     Rs_bellCommand,
+    Rs_vBellDuration,
+#endif
+    Rs_monitorCommand,
+    Rs_monitorTimeout,
     Rs_desktop,
 #ifndef NO_BACKSPACE_KEY
     Rs_backspace_key,
@@ -1232,7 +1237,7 @@ enum {
     Rs_holdExitTxt,	_Rs_holdExitTxt = MAX_PROFILES - 1 + Rs_holdExitTxt,
     Rs_holdExitTtl,	_Rs_holdExitTtl = MAX_PROFILES - 1 + Rs_holdExitTtl,
     Rs_titleFormat,	_Rs_titleFormat = MAX_PROFILES - 1 + Rs_titleFormat,
-    Rs_winTitleFormat,	_Rs_winTitleFormat = MAX_NFONTS - 1 + Rs_winTitleFormat,
+    Rs_winTitleFormat,	_Rs_winTitleFormat = MAX_PROFILES - 1 + Rs_winTitleFormat,
 
     NUM_RESOURCES
 } ;
