@@ -27,6 +27,9 @@
 
 #include "../config.h"
 #include "rxvt.h"
+#ifdef HAVE_WORDEXP_H
+# include <wordexp.h>
+#endif
 
 
 #ifdef HAVE_LIBXPM
@@ -706,8 +709,28 @@ void rxvt_draw_tabs (rxvt_t* r, Region region)
 	XArc	 	arcs[2];
 	XPoint	 	points[8];
 
-	if( page == ATAB(r) )
+	/*
+	 * Color the tab as active if the tab is active 
+	 * or
+	 * activity/inactivity is detected by the MonitorTab macro
+	 */
+
+	if( (page == ATAB(r)) || 
+ 	    ((NOT_NULL(&PVTS(r, page)->monitor_tab)) && 
+	     (PVTS(r,page)->monitor_tab == TAB_MON_NOTIFICATION)) 
+	  )
 	{
+	    /* 
+	     * disable activity/inactivity notification if current tab is
+	     * active tab
+	     */
+	    if ((page == ATAB(r)) && 
+		(PVTS(r,page)->monitor_tab == TAB_MON_NOTIFICATION))
+	    {
+	      rxvt_msg (DBG_INFO, DBG_MACROS,  
+		      "Macro MonitorTab: monitored tab %i is now the active tab", page);
+	      PVTS(r,page)->monitor_tab = TAB_MON_OFF;
+            }
 	    /*
 	     * Draw the active tab, and bottom line of the tabbar.
 	     */
@@ -1281,18 +1304,43 @@ rxvt_append_page( rxvt_t* r, int profile,
 	
 	else
 	{
-	    /* XXX Maybe better to use wordexp and expand ~ & $HOME here */
-	    len  = STRLEN( cwdOption );
+#ifdef HAVE_WORDEXP_H
+	    wordexp_t p;
+	    int wordexp_result = wordexp(cwdOption, &p, 0);
+	    char *filename;
 
-	    MIN_IT( len, PATH_MAX - 1 );
-	    STRNCPY( child_cwd, cwdOption, len );
-	    child_cwd[len] = 0;
+	    if( wordexp_result == 0 )
+	    {
+		if( p.we_wordc > 1)
+		    rxvt_msg( DBG_ERROR, DBG_TABBAR,
+			    "Too many words when expanding %s\n", cwdOption );
+		else
+		{
+		    filename = *p.we_wordv;
+
+		    len  = STRLEN( filename );
+		    MIN_IT( len, PATH_MAX - 1 );
+		    STRNCPY( child_cwd, filename, len );
+		    child_cwd[len] = 0;
+		}
+
+		wordfree( &p );
+	    }
+
+	    else
+	    {
+		rxvt_dbgmsg(( DBG_VERBOSE, DBG_TABBAR,
+			    "wordexp error code '%i', expanding '%s'\n",
+			    wordexp_result, filename ));
+	    }
+#endif /* HAVE_WORDEXP_H */
 	}
 
 	if( len > 0 && chdir( child_cwd ) == 0 )
 	{
 	    /* Now in working directory of ATAB */
-	    rxvt_dbgmsg ((DBG_DEBUG, DBG_TABBAR, "Running child in directory: %s\n", child_cwd ));
+	    rxvt_dbgmsg ((DBG_DEBUG, DBG_TABBAR,
+			"Running child in directory: %s\n", child_cwd ));
 
 	    /* Run command in this new directory. */
 	    LVTS(r)->cmd_fd =
@@ -1305,7 +1353,8 @@ rxvt_append_page( rxvt_t* r, int profile,
 	else
 	{
 	    /* Exec command in original directory. */
-	    rxvt_dbgmsg ((DBG_DEBUG, DBG_TABBAR, "Running child in original directory\n"));
+	    rxvt_dbgmsg(( DBG_DEBUG, DBG_TABBAR,
+			"Running child in original directory\n"));
 
 	    LVTS(r)->cmd_fd =
 		rxvt_run_command( r, LTAB(r), (const char**) argv );
