@@ -33,7 +33,7 @@
  *         BEGIN `INTERNAL' ROUTINE PROTOTYPES                        *
  *--------------------------------------------------------------------*/
 #ifndef NO_RESOURCES
-void  rxvt_get_xdefaults (rxvt_t*, FILE*, const char*);
+void  rxvt_get_xdefaults (rxvt_t*, FILE*, const char*, macro_priority_t);
 #endif
 /*--------------------------------------------------------------------*
  *         END   `INTERNAL' ROUTINE PROTOTYPES                        *
@@ -238,8 +238,17 @@ static const struct {
 	"Configuration file instead of ~/.mrxvtrc", 0),
 
 #ifndef NO_BELL
-    BOOL( "visualBell", "vb", Opt_visualBell,
-	    "visual bell" ),
+    BOOL( "visualBell", "vb", Opt_visualBell, "visual bell" ),
+    BOOL( "currentTabVBell", "ctvb", Opt_currentTabVBell,
+	    "visual bell only for active tab in focused window" ),
+    RSTRG( Rs_vBellDuration, "vBellDuration",
+	    "Duration (ms) of the visual bell", 0),
+    STRG( Rs_bellCommand, "bellCommand", "blc",
+	"string", "command to execute instead of beeping", 0),
+    STRG( Rs_monitorCommand, "monitorCommand", "mcmd",
+	"string", "command to execute if activity/inactivity was detected while monitoring", 0),
+    STRG( Rs_monitorTimeout, "monitorTimeout", "mto", "number",
+	"timeout in milliseconds for tab-monitoring", 0),
 # if ! defined(NO_MAPALERT) && defined(MAPALERT_OPTION)
     BOOL( "mapAlert", NULL, Opt_mapAlert, NULL ),
 # endif
@@ -462,8 +471,6 @@ static const struct {
 	    "borderless window" ),
     BOOL( "overrideRedirect", "or", Opt2_overrideRedirect,
 	    "override_redirect flag" ),
-    STRG(Rs_bellCommand, "bellCommand", "blc",
-	"string", "command to execute instead of beeping", 0),
     STRG(Rs_desktop, "desktop", "desktop",
 	"number", "desktop to place the program", 0),
     BOOL( "broadcast", "bcst", Opt2_broadcast,
@@ -808,7 +815,7 @@ rxvt_save_options (rxvt_t* r, const char* filename)
     int		i;
     FILE*	pf = fopen (filename, "w");
 
-    const char	*name = r->h->rs[Rs_name] ?: APL_NAME;
+    const char	*name = r->h->rs[Rs_name] ? r->h->rs[Rs_name] : APL_NAME;
 
     char	*tabs="\t\t\t\t\t";
 
@@ -908,7 +915,7 @@ rxvt_get_options(rxvt_t *r, int argc, const char *const *argv)
 	else
 	{
 	    bad_option = 1;
-	    rxvt_msg (DBG_ERROR, DBG_RESOURCE, "bad option \"%s\"", opt);
+	    rxvt_msg (DBG_ERROR, DBG_RESOURCE, "bad option \"%s\"\n", opt);
 	    continue;
 	}
 
@@ -1065,7 +1072,8 @@ rxvt_get_options(rxvt_t *r, int argc, const char *const *argv)
 
 		if (NOT_NULL(str))
 		    rxvt_parse_macros( r, opt + sizeof( "macro." ) - 1,
-			    str, False); /* Replace previous macros */
+			    str, 0); /* priority 0 = highest. All previous
+					macros get replaced. */
 	    }
 	    else
 	    {
@@ -1103,7 +1111,8 @@ rxvt_get_options(rxvt_t *r, int argc, const char *const *argv)
 	rxvt_usage(0);
 #endif
 
-	rxvt_msg (DBG_ERROR, DBG_RESOURCE,  "Use -h, -help or --help to get help" );
+	rxvt_msg (DBG_ERROR, DBG_RESOURCE,
+		"Use -h, -help or --help to get help\n" );
 	exit( EXIT_FAILURE );
     }
 
@@ -1117,19 +1126,13 @@ rxvt_get_options(rxvt_t *r, int argc, const char *const *argv)
  */
 /* INTPROTO */
 void
-rxvt_get_xdefaults(rxvt_t *r, FILE *stream, const char *name)
+rxvt_get_xdefaults(rxvt_t *r, FILE *stream, const char *name,
+	macro_priority_t priority)
 {
     unsigned int    len, lenstr;
     char TAINTED *  str;
     char	    buffer[256];
 
-    /*
-     * Macros defined with APL_CLASS or APL_SUBCLASS will not replace previous
-     * user defined macros
-     */
-    Bool    noReplace = !STRCMP( name, APL_CLASS )
-			    || !STRCMP( name, APL_SUBCLASS);
-
     rxvt_msg (DBG_INFO, DBG_RESOURCE, "rxvt_get_xdefaults (%s)\n", name);
 
     if (IS_NULL(stream))
@@ -1165,7 +1168,7 @@ rxvt_get_xdefaults(rxvt_t *r, FILE *stream, const char *name)
 	    }
 	}
 
-	if( !rxvt_parse_macros( r, str, NULL, noReplace) )
+	if( !rxvt_parse_macros( r, str, NULL, priority ) )
 	{
 	    for (entry = 0; entry < optList_size(); entry++)
 	    {
@@ -1307,6 +1310,11 @@ rxvt_extract_resources (
     FILE	   *fd = NULL;
     char	   *home;
 
+    macro_priority_t    priority = 1;   /* As resources get more general, we
+					   increment this value so that
+					   resources with lower priority are not
+					   overwritten */
+
 # if defined XAPPLOADDIR
 #  if defined(HAVE_XSETLOCALE) || defined(HAVE_SETLOCALE)
     /* Compute the path of the possibly available localized Rxvt file */ 
@@ -1372,11 +1380,11 @@ rxvt_extract_resources (
      * "XTerm" and "Rxvt" as class names.
      */
 
-    rxvt_get_xdefaults(r, fd, name);
-    rxvt_get_xdefaults(r, fd, APL_SUBCLASS);
-    rxvt_get_xdefaults(r, fd, APL_CLASS);
+    rxvt_get_xdefaults(r, fd, name, priority++);
+    rxvt_get_xdefaults(r, fd, APL_SUBCLASS, priority++);
+    rxvt_get_xdefaults(r, fd, APL_CLASS, priority++);
 #if 0
-    rxvt_get_xdefaults(r, fd, "");  /* partial match */
+    rxvt_get_xdefaults(r, fd, "", priority++);  /* partial match */
 #endif
     if (NOT_NULL(fd))
 	fclose(fd);
@@ -1391,13 +1399,13 @@ rxvt_extract_resources (
 	    ad = fopen(XAPPLOADDIR "/" APL_SUBCLASS, "r");
 	if (NOT_NULL(ad))
 	{
-	    rxvt_get_xdefaults(r, ad, APL_SUBCLASS);
+	    rxvt_get_xdefaults(r, ad, APL_SUBCLASS, priority++);
 #if 0
 	    /*
 	     * 2006-05-23 gi1242: If we don't use the X resource database, we
 	     * don't have to match the empty class.
 	     */
-	    rxvt_get_xdefaults(r, ad, "");
+	    rxvt_get_xdefaults(r, ad, "", priority++);
 #endif
 	    fclose(ad);
 	}
@@ -1411,7 +1419,7 @@ rxvt_extract_resources (
     if (NOTSET_OPTION(r, Opt2_noSysConfig) &&
         NOT_NULL(fd = fopen( PKG_CONF_DIR "/mrxvtrc", "r")))
     {
-	rxvt_get_xdefaults( r, fd, APL_SUBCLASS );
+	rxvt_get_xdefaults( r, fd, APL_SUBCLASS, priority++ );
 	fclose(fd);
     }
 
